RadarCollection object and related elements
===========================================

.. automodule:: sarpy.io.complex.sicd_elements.RadarCollection
    :members:
    :show-inheritance:
    :inherited-members:
